@@ -15,7 +15,7 @@ class DatetimeUtils:
     def to_utc_and_offset(d):
         if DatetimeUtils.is_naive(d):
             return d.replace(tzinfo=timezone.utc), None
-        offset = int(d.utcoffset() / timedelta(hours=1))
+        offset = int(d.utcoffset() / timedelta(seconds=1))
         offset = offset if offset != 0 else None
         return d.astimezone(timezone.utc), offset
 
